/* prompt.h */

/*
 * This file is part of CliFM
 *
 * Copyright (C) 2016-2023, L. Abramovich <leo.clifm@outlook.com>
 * All rights reserved.

 * CliFM is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * CliFM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
*/

#ifndef PROMPT_H
#define PROMPT_H

/* Mode macros for the prompt function */
#define PROMPT_UPDATE 0
#define PROMPT_SHOW   1
#define PROMPT_UPDATE_RUN_CMDS 2

__BEGIN_DECLS

char *prompt(const int);
char *decode_prompt(char *);
int  prompt_function(char **);

__END_DECLS

#endif /* PROMPT_H */
